pygeodesy.sphericalBase

Package pygeodesy :: Module sphericalBase |
[frames] | no frames]

# Module sphericalBase

(INTERNAL) Private spherical base classes `CartesianSphericalBase` and `LatLonSphericalBase` for sphericalNvector and sphericalTrigonometry.

A pure Python implementation of geodetic (lat-/longitude) functions, transcoded in part from JavaScript originals by (C) Chris Veness 2011-2024 and published under the same MIT Licence**, see Latitude/Longitude.

Version: 25.05.26

Classes
| CartesianSphericalBase (INTERNAL) Base class for spherical `Cartesian`s.
| LatLonSphericalBase (INTERNAL) Base class for spherical `LatLon`s.

Variables
| __all__ = `_ALL_LAZY.sphericalBase`